from setuptools import setup, find_packages

setup(name="pyliteconf",
      version="0.0.3.1",
      pakages=find_packages(),

      description='Library for creating configs on python',

      author='_co_cy_',
      author_email="step2038@mail.ru",

      url='https://github.com/co-cy/pyliteconf',
      zip_safe=False)
